# -*- coding: utf-8 -*-

import os
import re
import json
import sys
import time
import platform
import requests
import urlparse

from bs4 import BeautifulSoup

def create_ilovetim_and_username_folder(username):
    """
    create folder and username folder
    """

    system = platform.system()
    if system == 'Darwin':
        picfolder = 'Pictures'
    elif system == 'Windows':
        release = platform.release()
        if release in ['Vista', '7', '8']:
            picfolder = 'Pictures'
        elif release is 'XP':
            picfolder = os.path.join('My Documents', 'My Pictures')
        else:
            picfolder = ''
    else:
        picfolder = ''

    home = os.path.expanduser("~")
    base_folder = os.path.join(home, picfolder, 'ilovetim')

    if not os.path.exists(base_folder):
        os.mkdir(base_folder)

    folder = os.path.join(base_folder, "%s" % (username))

    if not os.path.exists(folder):
        os.mkdir(folder)

    return folder

def ilovetim(url):
    print 'start fetch url: %s' %(url)

    r = requests.get(
        url=url,
        headers={
            "Accept-Language": "zh-TW,zh;q=0.8,en-US;q=0.6,en;q=0.4",
        }
    )

    soup = BeautifulSoup(r.content, 'html.parser')


    parsed      = urlparse.urlparse(url)
    tid         = urlparse.parse_qs(parsed.query)['tid'][0]
    title       = soup.find_all('h1')[0].string
    images      = soup.find_all('img', class_="imglimit")
    folder      = create_ilovetim_and_username_folder(tid + title)

    for element in images:
        filename = element['src'].rsplit('/', 1)[1].split('?')[0]

        resp = requests.get(element['src'])
        print 'fetch %s' % (filename)

        with open(os.path.join(folder, filename), 'wb+') as f:
            f.write(resp.content)

    print 'Winter is comming'

def main():
    try:
        url = sys.argv[1]
    except IndexError:
        sys.exit('Please provide URL from ck101')

    ilovetim(url)



from setuptools import setup

license = open('LICENSE.txt').read()

setup(
    name='ilovetim',
    version='0.0.2',
    author='xwaynec',
    author_email='xwaynec@gmail.com',
    packages=['ilovetim'],
    url='https://github.com/xwaynec/ilovetimliao',
    license=license,
    description='Download images from instagram',
    test_suite='tests',
    long_description=open('README.md').read(),
    entry_points = {
        'console_scripts': [
            'ilovetim = ilovetim.ilovetim:main',
        ]
    },
    install_requires = [
        "beautifulsoup4==4.6.0",
        "certifi==2017.7.27.1",
        "chardet==3.0.4",
        "idna==2.5",
        "requests==2.18.3",
        "urllib3==1.22",
    ],
)
